"""Library to communicate with relays

"""

__version__ = '0.0.1'
__title__ = 'pynumato'
__description__ = 'Library to communicate with relay module - numato series'
#__uri__ = 'https://github.com/Tiempogithub/...'
#__doc__ = __description__ + ' <' + __uri__ + '>'
__author__ = 'Tiempo'
# For all support requests, please open a new issue on GitHub
__email__ = 'henitsoa.rakotomalala@tiempo-secure.com'
__copyright__ = 'Tiempo-Secure'
